package docar.archive.document;

import java.net.URL;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;

import docar.user.Writer;

/**
 * '문서' 클래스.
 *
 * @author "Sunny Kwak"
 */
public class Document {
	private String title;
	private Writer writer;
	private Set<String> keywords;
	private String abstraction;
	private URL originalLink;
	private Format format;
	private List<File> files;

	public Document(String title, Writer writer, Set<String> keywords,
			String abstraction, URL originalLink, Format format) {
		if (title == null || title.isEmpty()) {
			throw new IllegalArgumentException("title argument is missing");
		}
		if (writer == null) {
			throw new IllegalArgumentException("writer argument is missing");
		}
		if (originalLink == null) {
			throw new IllegalArgumentException(
					"originalLink argument is missing");
		}
		if (format == null) {
			throw new IllegalArgumentException("format argument is missing");
		}

		this.title = title;
		this.writer = writer;
		this.keywords = keywords;
		this.abstraction = abstraction;
		this.originalLink = originalLink;
		this.format = format;

		files = new ArrayList<File>();
	}

	/**
	 * @return 문서 제목
	 */
	public String getTitle() {
		return title;
	}

	/**
	 * @return 작성자
	 */
	public Writer getWriter() {
		return writer;
	}

	/**
	 * @return 키워드 목록
	 */
	public Set<String> getKeywords() {
		return keywords;
	}

	/**
	 * @return 문서 요약
	 */
	public String getAbstraction() {
		return abstraction;
	}

	/**
	 * @return 원본 링크
	 */
	public URL getOriginalLink() {
		return originalLink;
	}

	/**
	 * @return 문서 형식
	 */
	public Format getFormat() {
		return format;
	}

	/**
	 * @return 파일 목록
	 */
	public List<File> getFiles() {
		return files;
	}

	/**
	 * 버전 파일 추가
	 * 
	 * @param file
	 *            추가할 파일
	 */
	public void addFile(File file) {
		this.files.add(file);
	}
	
	/**
	 * 버전 파일 목록 설정
	 * 
	 * @param files 버전 파일 목록
	 */
	public void setFiles(List<File> files) {
		this.files = files;
	}

	/**
	 * 키워드 목록 설정
	 * 
	 * @param keywords
	 *            갱신할 키워드 목록
	 */
	public void setKeywords(Set<String> keywords) {
		this.keywords = keywords;
	}
	
	/**
	 * 문서 요약 설정
	 * 
	 * @param abstraction 변경할 요약
	 */
	public void setAbstraction(String abstraction) {
		this.abstraction = abstraction;
	}
	
}
