package docar.archive.document;

import java.sql.Date;

/**
 * <pre>
 * "파일 버전"은 문서의 원본 파일의 특정 버전에 대한 정보를 제공한다.
 * 
 * - 버전 순번 : 버전의 생성 순서이며 1부터 시작한다.
 * - 생성 일시 : 해당 버전을 등록한 날짜와 시간
 * - 버전 설명 : 해당 버전이 이전 버전과의 차이점 혹은 간단한 설명.
 * </pre>
 * 
 * @author "Sunny Kwak"
 */
public class FileVersion {
	private int sequence;
	private Date createDate;
	private String description;

	/**
	 * 파일 버전 생성자.
	 * 
	 * @param sequence
	 *            버전 순번.
	 * @param createDate
	 *            버전 생성 일시
	 * @param description
	 *            버전 설명
	 * @throws IllegalArgumentException
	 *             1보다 작은 순번 혹은 날짜가 입력되지 않은 경우 예외 발생.
	 */
	public FileVersion(int sequence, Date createDate, String description) {
		if (sequence < 1) {
			throw new IllegalArgumentException("sequence must greater than 0");
		}

		if (createDate == null) {
			throw new IllegalArgumentException("Must specify valid date");
		}

		this.sequence = sequence;
		this.createDate = createDate;
		this.description = description;
	}

	/**
	 * @return 파일 버전 순번 반환
	 */
	public int getSequence() {
		return sequence;
	}

	/**
	 * @return 파일 버전 생성 일시
	 */
	public Date getCreateDate() {
		return createDate;
	}

	/**
	 * @return 파일 버전 설명
	 */
	public String getDescription() {
		return description;
	}

}
